Class: Sevgi::Graphics::Document::Base

Inherits:
Object
  • Object
show all
Defined in:
lib/sevgi/showcase/passive.rb

Instance Method Summary collapse

Instance Method Details

#Save(*args, **kwargs) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Redirects showcase saves to stdout during passive integration tests.

Parameters:

  • args (Array<Object>)

    ignored save arguments

  • kwargs (Hash)

    render options

Returns:

  • (Object)

    F.out return value



13
# File 'lib/sevgi/showcase/passive.rb', line 13

def Save(*, **) = Out(**)

#Save!(*args, **kwargs) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Redirects forced showcase saves to stdout during passive integration tests.

Parameters:

  • args (Array<Object>)

    ignored save arguments

  • kwargs (Hash)

    render options

Returns:

  • (Object)

    F.out return value



21
# File 'lib/sevgi/showcase/passive.rb', line 21

def Save!(...) = Save(...)