Class: Sevgi::Graphics::Document::Base
- Inherits:
-
Object
- Object
- Sevgi::Graphics::Document::Base
- Defined in:
- lib/sevgi/showcase/passive.rb
Instance Method Summary collapse
-
#Save(*args, **kwargs) ⇒ Object
Redirects showcase saves to stdout during passive integration tests.
-
#Save!(*args, **kwargs) ⇒ Object
Redirects forced showcase saves to stdout during passive integration tests.
Instance Method Details
#Save(*args, **kwargs) ⇒ Object
13 |
# File 'lib/sevgi/showcase/passive.rb', line 13 def Save(*, **) = Out(**) |
#Save!(*args, **kwargs) ⇒ Object
21 |
# File 'lib/sevgi/showcase/passive.rb', line 21 def Save!(...) = Save(...) |